#
# spec file for package aardvark-dns
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aardvark-dns
Version:        1.7.0
Release:        2.1
Summary:        Authoritative dns server for A/AAAA container records
License:        Apache-2.0
URL:            https://github.com/containers/%{name}
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        cargo_config
BuildRequires:  cargo
BuildRequires:  cargo-packaging
# Disable this line if you wish to support all platforms.

%description
Aardvark-dns is an authoritative dns server for A/AAAA container records.
It can forward other requests to configured resolvers.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
cargo build --release
mkdir -p bin
cp target/release/%{name} bin/

%install
%make_install DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBEXECDIR=%{_libexecdir}

%files
%license LICENSE
%dir %{_libexecdir}/podman
%{_libexecdir}/podman/%{name}

%changelog
* Tue Jul 11 2023 Danish Prakash <danish.prakash@suse.com>
- Disable restricting builds only for tier1 platforms
  i.e. only for x86_64 and aarch64 and enable for all.
* Mon Jul  3 2023 danish.prakash@suse.com
- Update to version 1.7.0:
  * release v1.7.0
  * Update release notes for v1.7.0
  * fix(deps): update rust crate tokio to 1.29.0
  * fix(deps): update rust crate clap to 4.3.8
  * fix(deps): update rust crate clap to 4.3.5
  * run cargo update
  * [CI:BUILD] Packit: add Fedora downstream tasks
  * fix(deps): update rust crate clap to 4.3.4
  * chore(deps): update dependency containers/automation_images to v20230614
  * fix(deps): update rust crate clap to 4.3.3
  * fix(deps): update rust crate log to 0.4.19
  * fix(deps): update rust crate clap to 4.3.2
  * fix(deps): update rust crate clap to 4.3.1
  * cirrus: remove verify_vendor task
  * chore(deps): update dependency containers/automation_images to v20230601
  * fix(deps): update rust crate trust-dns-server to 0.22.1
  * chore(deps): update rust crate chrono to 0.4.26
  * fix(deps): update rust crate tokio to 1.28.2
  * fix(deps): update rust crate log to 0.4.18
  * chore(deps): update rust crate chrono to 0.4.25
  * fix(deps): update rust crate clap to 4.3.0
  * chore(deps): update dependency containers/automation_images to v20230517
  * fix(deps): update rust crate tokio to 1.28.1
  * chore(deps): update dependency containers/automation_images to v20230426
  * fix(deps): update rust crate clap to 4.2.7
  * fix(deps): update rust crate anyhow to 1.0.71
  * fix typo in makefile
  * fix(deps): update rust crate tokio to 1.28.0
  * fix(deps): update rust crate clap to 4.2.5
  * fix(deps): update rust crate syslog to ^6.1.0
  * fix(deps): update rust crate clap to 4.2.4
  * fix(deps): update rust crate clap to 4.2.3
  * fix(deps): update rust crate clap to v4
  * chore(deps): update dependency containers/automation_images to v20230405
  * bump to v1.7.0-dev
* Wed Apr 12 2023 danish.prakash@suse.com
- Update to version 1.6.0:
  * v1.6.0 release
  * Update release notes for v1.6.0
  * fix(deps): update rust crate tokio to 1.27.0
  * use lower TTL for contianer entries
  * fix(deps): update rust crate syslog to ^6.0.1
  * fix(deps): update rust crate futures-util to 0.3.28
  * chore(deps): update dependency containers/automation_images to v20230330
  * Disable Dependabot in favor of Renovate
  * chore(deps): update dependency containers/automation_images to v20230320
  * build(deps): bump futures-util from 0.3.26 to 0.3.27
  * [CI:BUILD] Packit: trigger builds on commit to main branch
  * build(deps): bump anyhow from 1.0.68 to 1.0.70
  * fix lint issue with new rust version 1.68
  * Cirrus: Update to newer CI VM images
  * build(deps): bump chrono from 0.4.23 to 0.4.24
  * build(deps): bump libc from 0.2.139 to 0.2.140
  * build(deps): bump async-broadcast from 0.5.0 to 0.5.1
  * build(deps): bump signal-hook from 0.3.14 to 0.3.15
  * build(deps): bump futures-util from 0.3.25 to 0.3.26
  * build(deps): bump tokio from 1.25.0 to 1.26.0
  * [CI:DOCS] Clarify packit related comments
  * [CI:BUILD] Packit: initial enablement
  * Allow custom cargo binary path
  * Switch to explicit platform list for `cargo vendor-filterer`
  * bump to v1.6.0-dev
  * Add renovate.json5
  * Cirrus: Groom rust cache before updating
* Fri Mar 17 2023 Danish Prakash <danish.prakash@suse.com>
- Fix libexecdir issue on Leap and SLE
* Tue Feb 14 2023 Danish Prakash <danish.prakash@suse.com>
- First version of aardvark-dns
